@@ -23,19 +23,20 @@
 #ifndef MINUET_IPLUGINCONTROLLER_H
 #define MINUET_IPLUGINCONTROLLER_H
 
-#include "minuetinterfacesexport.h"
+#include <interfaces/minuetinterfacesexport.h>
 
 #include <QObject>
 
 namespace Minuet
 {
-
 class MINUETINTERFACES_EXPORT IPluginController : public QObject
 {
     Q_OBJECT
 
 public:
-    ~IPluginController() override;
+    virtual ~IPluginController() override = default;
+
+    virtual QString errorString() const = 0;
 
 protected:
     explicit IPluginController(QObject *parent = 0);
